%define module_name	alsa
%define module_version	1.0.9a
%define module_release	alt1
%define module_source	ftp://ftp.alsa-project.org/pub/driver/alsa-driver-%module_version.tar.bz2
%define module_source_dir alsa-driver-%module_version

#### MODULE SOURCES ####
Name:          kernel-source-%module_name-%module_version
Version:       %module_version
Release:       %module_release
Summary:       Linux %module_name modules sources
License:       GPL
Group:         Development/Kernel
URL:           http://www.alsa-project.org/
BuildArch:     noarch
Provides:      kernel-source-%module_name = %module_version
Source0:       %module_source

Patch1: alsa-driver-0.9.8-intel8x0-blacklist.patch
Patch2: alsa-driver-1.0.9a-fm801-more-ids.patch
Patch4: alsa-driver-1.0.6a-alt-fix-compile.patch

Packager:       Kernel Maintainers Team <kernel@packages.altlinux.org>

#### KERNEL DOCUMENTATION ####
%package -n kernel-doc-%module_name-%module_version
Version:       %module_version
Summary:       Linux %module_name modules documentation
Group:         Development/Kernel

%description
%module_name modules sources for Linux kernel

%description -n kernel-doc-%module_name-%module_version
%module_name modules documentation for Linux kernel

#### KERNEL HEADERS ##########
%package -n kernel-headers-alsa
Summary: Header files for the %module_name modules system
Group: System/Kernel and hardware
Requires: kernel-headers
Obsoletes: alsa-driver-headers
Provides: alsa-driver-headers = %version-%release
Provides: kernel-headers-alsa-std-up = %version
Provides: kernel-headers-alsa-std-smp = %version

%description -n kernel-headers-alsa
The Advanced Linux Sound Architecture (ALSA) provides audio and MIDI
functionality to the Linux operating system. ALSA has the following
significant features:
1. Efficient support for all types of audio interfaces, from consumer
soundcards to professional multichannel audio interfaces.
2. Fully modularized sound drivers.
3. SMP and thread-safe design.
4. User space library (alsa-lib) to simplify application programming
and provide higher level functionality.
5. Support for the older OSS API, providing binary compatibility for
most OSS programs.

These are the C header files for the %module_name modules system,
which define structures and constants that are needed when building
most standard programs that use %module_name.



%prep
%setup -q -c

pushd %module_source_dir
%patch1 -p1
%patch2 -p1
%patch4 -p1

find . -name '*.orig' -delete
popd

%__mkdir_p include
ln -sf ../%module_source_dir/alsa-kernel/include include/sound

%build
# Test compilation of headers in userspace
TestHeader()
{
	echo "#include <sound/$1>" > test.c
	gcc -c -I. $RPM_OPT_FLAGS test.c
}

# These headers have no equivalent in libalsa-devel
pushd include
TestHeader asequencer.h
TestHeader asound.h
TestHeader asound_fm.h
popd

%install
mkdir -p %buildroot%_usrsrc/kernel/sources
mkdir -p %buildroot%_includedir/sound
mkdir -p %buildroot%_defaultdocdir/%module_name-doc-%module_version
cp -a %module_source_dir/FAQ \
    %buildroot%_defaultdocdir/%module_name-doc-%module_version
cp -a %module_source_dir/doc/{SOUNDCARDS,*.txt} \
    %buildroot%_defaultdocdir/%module_name-doc-%module_version
cp -a %module_source_dir/alsa-kernel/Documentation/*.{txt,html} \
    %buildroot%_defaultdocdir/%module_name-doc-%module_version
mv %module_source_dir kernel-source-%module_name-%module_version
tar -c kernel-source-%module_name-%module_version | bzip2 -c > \
    %buildroot%_usrsrc/kernel/sources/kernel-source-%module_name-%module_version.tar.bz2
cp -r kernel-source-%module_name-%module_version/alsa-kernel/include/* %buildroot%_includedir/sound

%files
%_usrsrc/*

%files -n kernel-doc-%module_name-%module_version
%doc %_defaultdocdir/%module_name-doc-%module_version

%files -n kernel-headers-alsa
%_includedir/sound

%changelog
* Fri Jun 03 2005 Sergey Vlasov <vsu@altlinux.ru> 1.0.9a-alt1
- 1.0.9a.
- Removed obsolete patches from CVS.
- Added:
  + alsa-driver-1.0.9a-fm801-more-ids.patch: add another FM801 PCI ID

* Tue Jan 25 2005 Sergey Vlasov <vsu@altlinux.ru> 1.0.8-alt1
- 1.0.8.
- Removed obsolete vortex_adbdma_resetup and aureal-quadfix patches.
- Added patches from CVS:
  + 01_pcxhr-firmware-load.patch: fix pcxhr firmware loading bugs
  + 02_azx-realtek-pciid.patch: new PCI subsystem ID
  + 03_doc-typo.patch: fix typo in the list of values for the ac97_quirk option
  + 04_azx-capture-loopback.patch: fix capture and analog loopback in the
    generic codec parser
  + 05_vx-firmware-state.patch: show the firmware loading state in proc file
  + 06_intel8x0-ich7-pciid.patch: add ICH7 device ID to snd-intel8x0
  + 07_ac97-ad1981-jack-sense.patch: fixed the default state of "Headphone Jack
    Sense" switch on AD1981x codecs (turning it on unconditionally was breaking
    sound on several Thinkpad models)
  + 08_usbaudio-quirks.patch: don't use broken legacy interfaces on M-Audio
    Quattro/Omnistudio
  + 09_atiixp-modem-fix.patch: workaround for buggy ATI IXP chips
  + 10_missing-includes.patch: add missing #include <linux/device.h>
  + 11_ice1712-quirks.patch: add support for Chaintech 9CJS
  + 12_atiixp-quirks.patch: HP Pavilion ZV5030US mute LED support
  + 13_intel8x0-quirks.patch: HP nc8000 mute LED support
  + 14_ac97-jack-sense-quirks.patch: enable 'Headphone Jack Sense' control on
    FSC Scenic-W
  + 15_usbmidi-quirks.patch: add support for Yamaha UC-MX, UC-KX, CLP-175,
    SPX2000
  + 16_ac97-quirks.patch: fix sound output on the ASUS W1000 laptop with the
    CMI9739 chip (use EAPD instead of SPDIF in).

* Sun Oct 17 2004 Sergey Vlasov <vsu@altlinux.ru> 1.0.6a-alt2
- Restored changes from 1.0.4-alt2 which were lost in 1.0.6a-alt1:
  + Added Aureal patches from Manual Jander
  + Added Provides: kernel-source-%%module_name = %%module_version
- Replaced aureal-2.6.6.diff.gz with
  alsa-driver-1.0.6a-vortex_adbdma_resetup.patch (the only part which did not
  get merged to the main ALSA tree for some reason).
- Added alsa-driver-1.0.6a-alt-fix-compile.patch: fix header compilation with
  old kernel headers (glibc-kernheaders) without __user definition.
- Added header compilation check to %%build.

* Sat Oct 09 2004 Sergey Vlasov <vsu@altlinux.ru> 1.0.6a-alt1
- 1.0.6a
- Removed obsolete patches:
   - alsa-driver-1.0.4-via82xx-quirk.patch
   - alsa-driver-1.0.4-atiixp-spdif-fix.patch
   - alsa-driver-1.0.4-ac97-cache-spdif.patch
   - alsa-driver-1.0.4-ac97-powerdown.patch
   - alsa-driver-1.0.4-intel8x0-20bit.patch

* Thu Jun 10 2004 Alexey Morozov <morozov@altlinux.org> 1.0.4-alt2
- Added Aureal patches from Manual Jander:
  * http://galadriel.mat.utfsm.cl/~mjander/aureal/alsa/aureal-2.6.6.diff.gz
  * aureal-quadfix.patch (http://lists.gnu.org/archive/html/openvortex-dev/2004-06/txtLq3yTP8Vl0.txt)
- Added Provides: kernel-source-%%module_name = %%module_version

* Mon Apr 05 2004 Sergey Vlasov <vsu@altlinux.ru> 1.0.4-alt1
- 1.0.4
- Added patches from CVS:
  - alsa-driver-1.0.4-via82xx-quirk.patch: added dxs_support and ac97_quirk
    entries for Arima notebook
  - alsa-driver-1.0.4-atiixp-spdif-fix.patch: fixed SPDIF support (48k only)
  - alsa-driver-1.0.4-ac97-cache-spdif.patch: fixed the possible ac97 register
    cache mismatch; added the detection of spdif sample rates
  - alsa-driver-1.0.4-ac97-powerdown.patch: fix access to wrong register when
    clearing powerdown bits
  - alsa-driver-1.0.4-intel8x0-20bit.patch: 20-bit sample format support (for
    ICH4 and later devices)

* Tue Mar 02 2004 Sergey Vlasov <vsu@altlinux.ru> 1.0.3-alt1
- 1.0.3
- dropped ac97-quirk patch (upstream)

* Wed Feb 04 2004 Sergey Vlasov <vsu@altlinux.ru> 1.0.2c-alt1
- 1.0.2c

* Tue Feb 03 2004 Sergey Vlasov <vsu@altlinux.ru> 1.0.2b-alt1
- 1.0.2b
- spec file cleanup
- moved patches from kernel-modules-alsa-* here
- fixed file lists for kernel-doc-alsa

* Fri Jan 09 2004 Sergey Vlasov <vsu@altlinux.ru> 1.0.1-alt1
- 1.0.1
- added URL

* Wed Oct 22 2003 Sergey Vlasov <vsu@altlinux.ru> 0.9.8-alt1
- 0.9.8

* Mon Oct 13 2003 Sergey Vlasov <vsu@altlinux.ru> 0.9.7-alt1c
- 0.9.7c

* Sat Oct 11 2003 Sergey Vlasov <vsu@altlinux.ru> 0.9.7-alt1b
- 0.9.7b

* Wed Oct 08 2003 Rider <rider@altlinux.ru> 0.9.7-alt1a
- 0.9.7a 

* Fri Sep 26 2003 Sergey Vlasov <vsu@altlinux.ru> 0.9.7-alt1
- 0.9.7
- removed %%kversion-%%krelease from Provides: alsa-driver-headers

* Wed Jul 30 2003 Peter Novodvorsky <nidd@altlinux.com> 0.9.6-alt2
- added Obsoletes: alsa-drivers-headers to -headers.

* Wed Jul 30 2003 Peter Novodvorsky <nidd@altlinux.com> 0.9.6-alt1
- 0.9.6

* Tue Jul 29 2003 Peter Novodvorsky <nidd@altlinux.com> 0.9.5-alt2
- headers are generated from source package now.

* Tue Jul 15 2003 Michael Shigorin <mike@altlinux.ru> 0.9.5-alt1
- 0.9.5

* Thu Jun 12 2003 Peter Novodvorsky <nidd@altlinux.com> 0.9.4-alt1
- new upstream

* Fri Apr 18 2003 Peter Novodvorsky <nidd@altlinux.com> 0.9.2-alt2
- adopting to new kernel policy.

* Thu Mar 20 2003 Peter Novodvorsky <nidd@altlinux.com> 0.9.2-alt1
- new upstream

* Wed Feb 19 2003 Peter Novodvorsky <nidd@altlinux.org> 0.9.1-alt1
- initial release of NGKPs
